@@ -261,53 +261,24 @@ def scRFE (adata, classOfInterest, nEstimators = 1000, randomState = 0, min_cell
     results_df = pd.DataFrame()
 
     score_df = {}
-    for i in tqdm(range(len(adata.obs[classOfInterest]))[0:3]):
 
-        for labelOfInterest in np.unique(dataMatrix.obs[classOfInterest])[0:3]:
 
-            dataMatrix_labelOfInterest = dataMatrix.copy()
+    for labelOfInterest in np.unique(dataMatrix.obs[classOfInterest]):
 
-            feature_selected, feature_importance, model_score, X_new, y =  makeOneForest(dataMatrix = dataMatrix,
-                classOfInterest = classOfInterest, labelOfInterest = labelOfInterest,
-                nEstimators = nEstimators, randomState = randomState,  min_cells = min_cells,
-                    keep_small_categories = keep_small_categories,
-                       nJobs = nJobs, oobScore = oobScore, Step= Step, Cv=Cv, verbosity=verbosity)
+        dataMatrix_labelOfInterest = dataMatrix.copy()
 
-            results_df = resultWrite (classOfInterest, results_df,
-                                labelOfInterest = labelOfInterest,
-                        feature_selected = feature_selected,
-                        feature_importance = feature_importance)
+        feature_selected, feature_importance, model_score, X_new, y =  makeOneForest(dataMatrix = dataMatrix,
+            classOfInterest = classOfInterest, labelOfInterest = labelOfInterest,
+            nEstimators = nEstimators, randomState = randomState,  min_cells = min_cells,
+                keep_small_categories = keep_small_categories,
+                   nJobs = nJobs, oobScore = oobScore, Step= Step, Cv=Cv, verbosity=verbosity)
+
+        results_df = resultWrite (classOfInterest, results_df,
+                            labelOfInterest = labelOfInterest,
+                    feature_selected = feature_selected,
+                    feature_importance = feature_importance)
+
+        score_df[labelOfInterest] = model_score
 
-            score_df[labelOfInterest] = model_score
-        pass
 
     return results_df,score_df
-
-
-def scRFEimplot(X_new,y):
-    """
-    Plots permutation importance of each feature selected by scRFE.
-    Parameters
-    ----------
-    X_new : sparse matrix
-    Transformed array of selected features.
-    y : pandas series
-    Target labels.
-    Returns
-    -------
-    plt : module matplotlib.pyplot
-    Can be pickled, then saved.
-    """
-    rf = RandomForestClassifier(random_state=0).fit(X_new, y)
-    result = permutation_importance(rf, X_new.todense(), y, n_repeats=10, random_state=0,
-        n_jobs=-1)
-    fig, ax = plt.subplots()
-    sorted_idx = result.importances_mean.argsort()
-    ax.boxplot(result.importances[sorted_idx].T*100,
-        vert=False, labels=range(X_new.shape[1]))
-    ax.set_title("Permutation Importance of each feature")
-    ax.set_ylabel("Features")
-    fig.tight_layout()
-
-    plt.show()
-    return plt
